summaryrefslogtreecommitdiffstats
path: root/krita/core/kis_rect.h
diff options
context:
space:
mode:
Diffstat (limited to 'krita/core/kis_rect.h')
-rw-r--r--krita/core/kis_rect.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/krita/core/kis_rect.h b/krita/core/kis_rect.h
index 268b64eb..30a729c8 100644
--- a/krita/core/kis_rect.h
+++ b/krita/core/kis_rect.h
@@ -18,12 +18,12 @@
#ifndef KIS_RECT_H_
#define KIS_RECT_H_
-#include <qrect.h>
+#include <tqrect.h>
#include <KoRect.h>
#include "kis_point.h"
/**
* A double-based rect class that can return a QRect that encloses the KisRect.
*/
class KisRect : public KoRect
{
@@ -32,18 +32,18 @@ public:
KisRect() {}
KisRect(double x, double y, double w, double h) : super(x, y, w, h) {}
KisRect(const KisPoint& topLeft, const KisPoint& bottomRight) : super(topLeft, bottomRight) {}
- KisRect(const QRect& qr) : super(qr.x(), qr.y(), qr.width(), qr.height()) {}
+ KisRect(const TQRect& qr) : super(qr.x(), qr.y(), qr.width(), qr.height()) {}
KisRect(const KoRect& r) : super(r) {}
/**
* Return the QRect that encloses this KisRect.
*/
- QRect qRect() const;
+ TQRect qRect() const;
private:
// Use qRect() which uses ceil() and floor() to return a rectangle
- // 'enclosing' the rectangle, whereas toQRect rounds the points.
- QRect toQRect() const;
+ // 'enclosing' the rectangle, whereas toTQRect rounds the points.
+ TQRect toTQRect() const;
};
#endif // KIS_RECT_H_
@@ -18,12 +18,12 @@
#include "kis_point.h"
/**
- * A double-based rect class that can return a QRect that encloses the KisRect.
+ * A double-based rect class that can return a TQRect that encloses the KisRect.
*/
class KisRect : public KoRect
@@ -32,18 +32,18 @@ public:
KisRect(const KoRect& r) : super(r) {}
/**
- * Return the QRect that encloses this KisRect.
+ * Return the TQRect that encloses this KisRect.
*/